diff --git a/gcc/attribs.cc b/gcc/attribs.cc
index 189f56a6e48..750dc322e97 100644
--- a/gcc/attribs.cc
+++ b/gcc/attribs.cc
@@ -2655,7 +2655,7 @@ test_attribute_exclusions ()
 }
 
 void
-attribute_c_tests ()
+attribute_cc_tests ()
 {
   test_attribute_exclusions ();
 }
diff --git a/gcc/bitmap.cc b/gcc/bitmap.cc
index 69b9d53eec9..88c329f9325 100644
--- a/gcc/bitmap.cc
+++ b/gcc/bitmap.cc
@@ -2976,7 +2976,7 @@ test_aligned_chunk (unsigned num_bits)
 /* Run all of the selftests within this file.  */
 
 void
-bitmap_c_tests ()
+bitmap_cc_tests ()
 {
   test_gc_alloc ();
   test_set_range ();
diff --git a/gcc/c-family/c-common.cc b/gcc/c-family/c-common.cc
index d9674ea0581..f56f6df8fe3 100644
--- a/gcc/c-family/c-common.cc
+++ b/gcc/c-family/c-common.cc
@@ -9096,7 +9096,7 @@ test_fold_for_warn ()
 /* Run all of the selftests within this file.  */
 
 static void
-c_common_c_tests ()
+c_common_cc_tests ()
 {
   test_fold_for_warn ();
 }
@@ -9106,10 +9106,10 @@ c_common_c_tests ()
 void
 c_family_tests (void)
 {
-  c_common_c_tests ();
-  c_format_c_tests ();
-  c_indentation_c_tests ();
-  c_pretty_print_c_tests ();
+  c_common_cc_tests ();
+  c_format_cc_tests ();
+  c_indentation_cc_tests ();
+  c_pretty_print_cc_tests ();
   c_spellcheck_cc_tests ();
 }
 
diff --git a/gcc/c-family/c-common.h b/gcc/c-family/c-common.h
index ee0c4de2a05..28c73fe2847 100644
--- a/gcc/c-family/c-common.h
+++ b/gcc/c-family/c-common.h
@@ -1512,9 +1512,9 @@ extern tree braced_lists_to_strings (tree, tree);
 namespace selftest {
   /* Declarations for specific families of tests within c-family,
      by source file, in alphabetical order.  */
-  extern void c_format_c_tests (void);
-  extern void c_indentation_c_tests (void);
-  extern void c_pretty_print_c_tests (void);
+  extern void c_format_cc_tests (void);
+  extern void c_indentation_cc_tests (void);
+  extern void c_pretty_print_cc_tests (void);
   extern void c_spellcheck_cc_tests (void);
 
   /* The entrypoint for running all of the above tests.  */
diff --git a/gcc/c-family/c-format.cc b/gcc/c-family/c-format.cc
index d7878b7880c..a2affdacd7c 100644
--- a/gcc/c-family/c-format.cc
+++ b/gcc/c-family/c-format.cc
@@ -5424,7 +5424,7 @@ test_type_mismatch_range_labels ()
 /* Run all of the selftests within this file.  */
 
 void
-c_format_c_tests ()
+c_format_cc_tests ()
 {
   test_get_modifier_for_format_len ();
   test_get_format_for_type_printf ();
diff --git a/gcc/c-family/c-indentation.cc b/gcc/c-family/c-indentation.cc
index 30c9b252a6f..85a3ae1b303 100644
--- a/gcc/c-family/c-indentation.cc
+++ b/gcc/c-family/c-indentation.cc
@@ -804,7 +804,7 @@ test_get_visual_column ()
 /* Run all of the selftests within this file.  */
 
 void
-c_indentation_c_tests ()
+c_indentation_cc_tests ()
 {
   test_next_tab_stop ();
   test_get_visual_column ();
diff --git a/gcc/c-family/c-pretty-print.cc b/gcc/c-family/c-pretty-print.cc
index 0b4256c7ac9..ceedaea962a 100644
--- a/gcc/c-family/c-pretty-print.cc
+++ b/gcc/c-family/c-pretty-print.cc
@@ -2999,7 +2999,7 @@ test_location_wrappers ()
 /* Run all of the selftests within this file.  */
 
 void
-c_pretty_print_c_tests ()
+c_pretty_print_cc_tests ()
 {
   test_location_wrappers ();
 }
diff --git a/gcc/cgraph.cc b/gcc/cgraph.cc
index ea8db2f4b8c..b923a59ab0c 100644
--- a/gcc/cgraph.cc
+++ b/gcc/cgraph.cc
@@ -4077,7 +4077,7 @@ cgraph_node::get_fun () const
    within the same process.  For use by toplev::finalize.  */
 
 void
-cgraph_c_finalize (void)
+cgraph_cc_finalize (void)
 {
   nested_function_info::release ();
   thunk_info::release ();
@@ -4261,7 +4261,7 @@ test_symbol_table_test ()
 /* Run all of the selftests within this file.  */
 
 void
-cgraph_c_tests ()
+cgraph_cc_tests ()
 {
   test_symbol_table_test ();
 }
diff --git a/gcc/cgraph.h b/gcc/cgraph.h
index 43fc94e69ea..8c512b648ee 100644
--- a/gcc/cgraph.h
+++ b/gcc/cgraph.h
@@ -2568,7 +2568,7 @@ asmname_hasher::equal (symtab_node *n, const_tree t)
 }
 
 /* In cgraph.cc  */
-void cgraph_c_finalize (void);
+void cgraph_cc_finalize (void);
 void release_function_body (tree);
 cgraph_indirect_call_info *cgraph_allocate_init_indirect_info (void);
 
@@ -2579,7 +2579,7 @@ const char* cgraph_inline_failed_string (cgraph_inline_failed_t);
 cgraph_inline_failed_type_t cgraph_inline_failed_type (cgraph_inline_failed_t);
 
 /* In cgraphunit.cc  */
-void cgraphunit_c_finalize (void);
+void cgraphunit_cc_finalize (void);
 int tp_first_run_node_cmp (const void *pa, const void *pb);
 
 /* In symtab-thunks.cc  */
diff --git a/gcc/cgraphunit.cc b/gcc/cgraphunit.cc
index e043f9f12bc..01f4e28204e 100644
--- a/gcc/cgraphunit.cc
+++ b/gcc/cgraphunit.cc
@@ -2535,7 +2535,7 @@ symbol_table::finalize_compilation_unit (void)
    within the same process.  For use by toplev::finalize.  */
 
 void
-cgraphunit_c_finalize (void)
+cgraphunit_cc_finalize (void)
 {
   gcc_assert (cgraph_new_nodes.length () == 0);
   cgraph_new_nodes.truncate (0);
diff --git a/gcc/convert.cc b/gcc/convert.cc
index 02997d3e88b..25cc3ff3bd1 100644
--- a/gcc/convert.cc
+++ b/gcc/convert.cc
@@ -1199,7 +1199,7 @@ test_convert_to_integer_maybe_fold ()
 /* Run all of the selftests within this file.  */
 
 void
-convert_c_tests ()
+convert_cc_tests ()
 {
   test_convert_to_integer_maybe_fold ();
 }
diff --git a/gcc/cp/cp-lang.cc b/gcc/cp/cp-lang.cc
index 7861f93ff21..7c8b94741fa 100644
--- a/gcc/cp/cp-lang.cc
+++ b/gcc/cp/cp-lang.cc
@@ -278,8 +278,8 @@ run_cp_tests (void)
   c_family_tests ();
 
   /* Additional C++-specific tests.  */
-  cp_pt_c_tests ();
-  cp_tree_c_tests ();
+  cp_pt_cc_tests ();
+  cp_tree_cc_tests ();
 }
 
 } // namespace selftest
diff --git a/gcc/cp/cp-tree.h b/gcc/cp/cp-tree.h
index e428df06ea2..186c54424a6 100644
--- a/gcc/cp/cp-tree.h
+++ b/gcc/cp/cp-tree.h
@@ -8641,8 +8641,8 @@ namespace selftest {
 
   /* Declarations for specific families of tests within cp,
      by source file, in alphabetical order.  */
-  extern void cp_pt_c_tests ();
-  extern void cp_tree_c_tests (void);
+  extern void cp_pt_cc_tests ();
+  extern void cp_tree_cc_tests (void);
 } // namespace selftest
 #endif /* #if CHECKING_P */
 
diff --git a/gcc/cp/pt.cc b/gcc/cp/pt.cc
index 4a2b33ec940..d4f20b14f13 100644
--- a/gcc/cp/pt.cc
+++ b/gcc/cp/pt.cc
@@ -30583,7 +30583,7 @@ test_type_dependent_expression_p ()
 /* Run all of the selftests within this file.  */
 
 void
-cp_pt_c_tests ()
+cp_pt_cc_tests ()
 {
   test_build_non_dependent_expr ();
   test_type_dependent_expression_p ();
diff --git a/gcc/cp/tree.cc b/gcc/cp/tree.cc
index d27f64fe9bf..bcd44e73921 100644
--- a/gcc/cp/tree.cc
+++ b/gcc/cp/tree.cc
@@ -6167,7 +6167,7 @@ test_lvalue_kind ()
 /* Run all of the selftests within this file.  */
 
 void
-cp_tree_c_tests ()
+cp_tree_cc_tests ()
 {
   test_lvalue_kind ();
 }
diff --git a/gcc/dbgcnt.cc b/gcc/dbgcnt.cc
index 5dd00d6befb..11a8171d943 100644
--- a/gcc/dbgcnt.cc
+++ b/gcc/dbgcnt.cc
@@ -272,7 +272,7 @@ test_sorted_dbg_counters ()
 }
 
 void
-dbgcnt_c_tests ()
+dbgcnt_cc_tests ()
 {
   test_sorted_dbg_counters ();
 }
diff --git a/gcc/diagnostic-show-locus.cc b/gcc/diagnostic-show-locus.cc
index 0465788362b..6eafe19785f 100644
--- a/gcc/diagnostic-show-locus.cc
+++ b/gcc/diagnostic-show-locus.cc
@@ -5658,7 +5658,7 @@ test_line_numbers_multiline_range ()
 /* Run all of the selftests within this file.  */
 
 void
-diagnostic_show_locus_c_tests ()
+diagnostic_show_locus_cc_tests ()
 {
   test_line_span ();
 
diff --git a/gcc/diagnostic.cc b/gcc/diagnostic.cc
index 97e2e2c862e..f5f43d5e9a7 100644
--- a/gcc/diagnostic.cc
+++ b/gcc/diagnostic.cc
@@ -2466,7 +2466,7 @@ test_num_digits ()
 /* Run all of the selftests within this file.  */
 
 void
-diagnostic_c_tests ()
+diagnostic_cc_tests ()
 {
   test_print_escaped_string ();
   test_print_parseable_fixits_none ();
diff --git a/gcc/dumpfile.cc b/gcc/dumpfile.cc
index 44ee66f9f0a..ac79aa09245 100644
--- a/gcc/dumpfile.cc
+++ b/gcc/dumpfile.cc
@@ -2766,7 +2766,7 @@ test_pr87025 ()
 /* Run all of the selftests within this file.  */
 
 void
-dumpfile_c_tests ()
+dumpfile_cc_tests ()
 {
   test_impl_location ();
   for_each_line_table_case (test_capture_of_dump_calls);
diff --git a/gcc/dwarf2out.cc b/gcc/dwarf2out.cc
index 62b468d4ad9..f3bd322d901 100644
--- a/gcc/dwarf2out.cc
+++ b/gcc/dwarf2out.cc
@@ -33058,7 +33058,7 @@ dwarf2out_early_finish (const char *filename)
    within the same process.  For use by toplev::finalize.  */
 
 void
-dwarf2out_c_finalize (void)
+dwarf2out_cc_finalize (void)
 {
   last_var_location_insn = NULL;
   cached_next_real_insn = NULL;
diff --git a/gcc/dwarf2out.h b/gcc/dwarf2out.h
index ab2200bb8ec..656ef94afde 100644
--- a/gcc/dwarf2out.h
+++ b/gcc/dwarf2out.h
@@ -419,7 +419,7 @@ struct fixed_point_type_info
     } scale_factor;
 };
 
-void dwarf2out_c_finalize (void);
+void dwarf2out_cc_finalize (void);
 
 /* Some DWARF internals are exposed for the needs of DWARF-based debug
    formats.  */
diff --git a/gcc/edit-context.cc b/gcc/edit-context.cc
index 92715f64fc8..6879ddd41b4 100644
--- a/gcc/edit-context.cc
+++ b/gcc/edit-context.cc
@@ -1788,7 +1788,7 @@ test_applying_fixits_column_validation (const line_table_case &case_)
 /* Run all of the selftests within this file.  */
 
 void
-edit_context_c_tests ()
+edit_context_cc_tests ()
 {
   test_get_content ();
   for_each_line_table_case (test_applying_fixits_insert_before);
diff --git a/gcc/et-forest.cc b/gcc/et-forest.cc
index a1b1f574232..ebdcccb9f1d 100644
--- a/gcc/et-forest.cc
+++ b/gcc/et-forest.cc
@@ -872,7 +872,7 @@ test_disconnected_nodes ()
 /* Run all of the selftests within this file.  */
 
 void
-et_forest_c_tests ()
+et_forest_cc_tests ()
 {
   test_single_node ();
   test_simple_tree ();
diff --git a/gcc/fibonacci_heap.cc b/gcc/fibonacci_heap.cc
index 9911757a556..f4b52d6e3af 100644
--- a/gcc/fibonacci_heap.cc
+++ b/gcc/fibonacci_heap.cc
@@ -279,7 +279,7 @@ test_struct_key ()
 /* Run all of the selftests within this file.  */
 
 void
-fibonacci_heap_c_tests ()
+fibonacci_heap_cc_tests ()
 {
   test_empty_heap ();
   test_basic_heap_operations ();
diff --git a/gcc/fold-const.cc b/gcc/fold-const.cc
index ff6a74928a8..808f6eb1462 100644
--- a/gcc/fold-const.cc
+++ b/gcc/fold-const.cc
@@ -16775,7 +16775,7 @@ test_vec_duplicate_folding ()
 /* Run all of the selftests within this file.  */
 
 void
-fold_const_c_tests ()
+fold_const_cc_tests ()
 {
   test_arithmetic_folding ();
   test_vector_folding ();
diff --git a/gcc/function-tests.cc b/gcc/function-tests.cc
index a6ecfdf3857..7d7761569ad 100644
--- a/gcc/function-tests.cc
+++ b/gcc/function-tests.cc
@@ -687,7 +687,7 @@ test_expansion_to_rtl ()
 /* Run all of the selftests within this file.  */
 
 void
-function_tests_c_tests ()
+function_tests_cc_tests ()
 {
   test_fndecl_int_void ();
   test_fndecl_float_intchar ();
diff --git a/gcc/gcse.cc b/gcc/gcse.cc
index 1e3113d0e0e..b67353143a2 100644
--- a/gcc/gcse.cc
+++ b/gcc/gcse.cc
@@ -4128,7 +4128,7 @@ make_pass_rtl_hoist (gcc::context *ctxt)
    within the same process.  For use by toplev::finalize.  */
 
 void
-gcse_c_finalize (void)
+gcse_cc_finalize (void)
 {
   test_insn = NULL;
 }
diff --git a/gcc/gcse.h b/gcc/gcse.h
index ba5ee56cff9..4a201f34d78 100644
--- a/gcc/gcse.h
+++ b/gcc/gcse.h
@@ -39,7 +39,7 @@ extern struct target_gcse *this_target_gcse;
 #define this_target_gcse (&default_target_gcse)
 #endif
 
-void gcse_c_finalize (void);
+void gcse_cc_finalize (void);
 extern bool gcse_or_cprop_is_too_expensive (const char *);
 
 #endif
diff --git a/gcc/ggc-tests.cc b/gcc/ggc-tests.cc
index cc5f913a633..620989489b6 100644
--- a/gcc/ggc-tests.cc
+++ b/gcc/ggc-tests.cc
@@ -462,7 +462,7 @@ namespace selftest {
 /* Run all of the selftests within this file.  */
 
 void
-ggc_tests_c_tests ()
+ggc_tests_cc_tests ()
 {
   test_basic_struct ();
   test_length ();
diff --git a/gcc/gimple-ssa-store-merging.cc b/gcc/gimple-ssa-store-merging.cc
index 0571cf7d0e6..eb70d90a45c 100644
--- a/gcc/gimple-ssa-store-merging.cc
+++ b/gcc/gimple-ssa-store-merging.cc
@@ -5633,7 +5633,7 @@ verify_clear_bit_region_be (void)
 /* Run all of the selftests within this file.  */
 
 void
-store_merging_c_tests (void)
+store_merging_cc_tests (void)
 {
   verify_shift_bytes_in_array_left ();
   verify_shift_bytes_in_array_right ();
diff --git a/gcc/gimple.cc b/gcc/gimple.cc
index 4c02df5aeea..5559e56d460 100644
--- a/gcc/gimple.cc
+++ b/gcc/gimple.cc
@@ -3510,7 +3510,7 @@ test_return_without_value ()
 /* Run all of the selftests within this file.  */
 
 void
-gimple_c_tests ()
+gimple_cc_tests ()
 {
   test_assign_single ();
   test_assign_binop ();
diff --git a/gcc/hash-map-tests.cc b/gcc/hash-map-tests.cc
index eea661a94f1..c7d3dda8e03 100644
--- a/gcc/hash-map-tests.cc
+++ b/gcc/hash-map-tests.cc
@@ -467,7 +467,7 @@ test_nonzero_empty_key ()
 /* Run all of the selftests within this file.  */
 
 void
-hash_map_tests_c_tests ()
+hash_map_tests_cc_tests ()
 {
   test_map_of_strings_to_int ();
   test_map_of_int_to_strings ();
diff --git a/gcc/hash-set-tests.cc b/gcc/hash-set-tests.cc
index 6cab17a338b..de5c0e7a903 100644
--- a/gcc/hash-set-tests.cc
+++ b/gcc/hash-set-tests.cc
@@ -293,7 +293,7 @@ test_set_of_type_with_ctor_and_dtor ()
 /* Run all of the selftests within this file.  */
 
 void
-hash_set_tests_c_tests ()
+hash_set_tests_cc_tests ()
 {
   test_set_of_strings ();
   test_set_of_type_with_ctor_and_dtor ();
diff --git a/gcc/input.cc b/gcc/input.cc
index 4a92e552531..b3970613d81 100644
--- a/gcc/input.cc
+++ b/gcc/input.cc
@@ -3885,7 +3885,7 @@ void test_cpp_utf8 ()
 /* Run all of the selftests within this file.  */
 
 void
-input_c_tests ()
+input_cc_tests ()
 {
   test_linenum_comparisons ();
   test_should_have_column_data_p ();
diff --git a/gcc/ipa-cp.cc b/gcc/ipa-cp.cc
index e16015f937f..453e9c93cc3 100644
--- a/gcc/ipa-cp.cc
+++ b/gcc/ipa-cp.cc
@@ -6630,7 +6630,7 @@ make_pass_ipa_cp (gcc::context *ctxt)
    within the same process.  For use by toplev::finalize.  */
 
 void
-ipa_cp_c_finalize (void)
+ipa_cp_cc_finalize (void)
 {
   base_count = profile_count::uninitialized ();
   overall_size = 0;
diff --git a/gcc/ipa-fnsummary.cc b/gcc/ipa-fnsummary.cc
index 7e7afb082c1..0d7e395c846 100644
--- a/gcc/ipa-fnsummary.cc
+++ b/gcc/ipa-fnsummary.cc
@@ -4966,7 +4966,7 @@ make_pass_ipa_fn_summary (gcc::context *ctxt)
    within the same process.  For use by toplev::finalize.  */
 
 void
-ipa_fnsummary_c_finalize (void)
+ipa_fnsummary_cc_finalize (void)
 {
   ipa_free_fn_summary ();
 }
diff --git a/gcc/ipa-fnsummary.h b/gcc/ipa-fnsummary.h
index 34c2398f664..e1f1d1b839c 100644
--- a/gcc/ipa-fnsummary.h
+++ b/gcc/ipa-fnsummary.h
@@ -428,7 +428,7 @@ void evaluate_properties_for_edge (struct cgraph_edge *e,
 				   ipa_auto_call_arg_values *avals,
 				   bool compute_contexts);
 
-void ipa_fnsummary_c_finalize (void);
+void ipa_fnsummary_cc_finalize (void);
 HOST_WIDE_INT ipa_get_stack_frame_offset (struct cgraph_node *node);
 void ipa_remove_from_growth_caches (struct cgraph_edge *edge);
 
diff --git a/gcc/ipa-modref-tree.cc b/gcc/ipa-modref-tree.cc
index e0fc92f31b2..97e497accf2 100644
--- a/gcc/ipa-modref-tree.cc
+++ b/gcc/ipa-modref-tree.cc
@@ -1007,7 +1007,7 @@ test_merge ()
 
 
 void
-ipa_modref_tree_c_tests ()
+ipa_modref_tree_cc_tests ()
 {
   test_insert_search_collapse ();
   test_merge ();
diff --git a/gcc/ipa-modref-tree.h b/gcc/ipa-modref-tree.h
index 16118008467..edb3b49374a 100644
--- a/gcc/ipa-modref-tree.h
+++ b/gcc/ipa-modref-tree.h
@@ -738,8 +738,6 @@ struct GTY((user)) modref_tree
   }
 };
 
-void modref_c_tests ();
-
 void gt_ggc_mx (modref_tree <int>* const&);
 void gt_ggc_mx (modref_tree <tree_node*>* const&);
 void gt_pch_nx (modref_tree <int>* const&);
diff --git a/gcc/ipa-modref.cc b/gcc/ipa-modref.cc
index 37b5355e622..ad5cfd6507f 100644
--- a/gcc/ipa-modref.cc
+++ b/gcc/ipa-modref.cc
@@ -5490,7 +5490,7 @@ pass_ipa_modref::execute (function *)
 /* Summaries must stay alive until end of compilation.  */
 
 void
-ipa_modref_c_finalize ()
+ipa_modref_cc_finalize ()
 {
   if (optimization_summaries)
     ggc_delete (optimization_summaries);
diff --git a/gcc/ipa-modref.h b/gcc/ipa-modref.h
index 2f71e151a43..642108ae5dd 100644
--- a/gcc/ipa-modref.h
+++ b/gcc/ipa-modref.h
@@ -73,7 +73,7 @@ struct GTY(()) modref_summary
 
 modref_summary *get_modref_function_summary (cgraph_node *func);
 modref_summary *get_modref_function_summary (gcall *call, bool *interposed);
-void ipa_modref_c_finalize ();
+void ipa_modref_cc_finalize ();
 void ipa_merge_modref_summary_after_inlining (cgraph_edge *e);
 
 /* All flags that are implied by the ECF_CONST functions.  */
diff --git a/gcc/ipa-prop.h b/gcc/ipa-prop.h
index 12f76265681..553adfc9f35 100644
--- a/gcc/ipa-prop.h
+++ b/gcc/ipa-prop.h
@@ -1189,6 +1189,6 @@ tree build_ref_for_offset (location_t, tree, poly_int64, bool, tree,
 			   gimple_stmt_iterator *, bool);
 
 /* In ipa-cp.cc  */
-void ipa_cp_c_finalize (void);
+void ipa_cp_cc_finalize (void);
 
 #endif /* IPA_PROP_H */
diff --git a/gcc/ipa-reference.cc b/gcc/ipa-reference.cc
index a2f2fadd565..67e0c85a95e 100644
--- a/gcc/ipa-reference.cc
+++ b/gcc/ipa-reference.cc
@@ -1322,7 +1322,7 @@ make_pass_ipa_reference (gcc::context *ctxt)
    within the same process.  For use by toplev::finalize.  */
 
 void
-ipa_reference_c_finalize (void)
+ipa_reference_cc_finalize (void)
 {
   if (ipa_ref_opt_sum_summaries != NULL)
     {
diff --git a/gcc/ipa-reference.h b/gcc/ipa-reference.h
index be25beb361a..2048e4b81b1 100644
--- a/gcc/ipa-reference.h
+++ b/gcc/ipa-reference.h
@@ -24,7 +24,7 @@ along with GCC; see the file COPYING3.  If not see
 /* In ipa-reference.cc  */
 bitmap ipa_reference_get_read_global (struct cgraph_node *fn);
 bitmap ipa_reference_get_written_global (struct cgraph_node *fn);
-void ipa_reference_c_finalize (void);
+void ipa_reference_cc_finalize (void);
 int ipa_reference_var_uid (tree t);
 
 #endif  /* GCC_IPA_REFERENCE_H  */
diff --git a/gcc/ira-costs.cc b/gcc/ira-costs.cc
index 1e4cf5a35e4..964c94a06ef 100644
--- a/gcc/ira-costs.cc
+++ b/gcc/ira-costs.cc
@@ -2411,7 +2411,7 @@ ira_adjust_equiv_reg_cost (unsigned regno, int cost)
 }
 
 void
-ira_costs_c_finalize (void)
+ira_costs_cc_finalize (void)
 {
   this_target_ira_int->free_ira_costs ();
 }
diff --git a/gcc/ira.h b/gcc/ira.h
index 9a222762f15..c12827378e4 100644
--- a/gcc/ira.h
+++ b/gcc/ira.h
@@ -216,7 +216,7 @@ extern void ira_restore_scratches (FILE *dump_file);
 extern void ira_nullify_asm_goto (rtx_insn *insn);
 
 /* ira-costs.cc */
-extern void ira_costs_c_finalize (void);
+extern void ira_costs_cc_finalize (void);
 
 /* ira-lives.cc */
 extern rtx non_conflicting_reg_copy_p (rtx_insn *);
diff --git a/gcc/opt-suggestions.cc b/gcc/opt-suggestions.cc
index 84a6f261a8a..33f298560a1 100644
--- a/gcc/opt-suggestions.cc
+++ b/gcc/opt-suggestions.cc
@@ -396,7 +396,7 @@ test_completion_garbage (option_proposer &proposer)
 /* Run all of the selftests within this file.  */
 
 void
-opt_proposer_c_tests ()
+opt_suggestions_cc_tests ()
 {
   option_proposer proposer;
 
diff --git a/gcc/opts.cc b/gcc/opts.cc
index 17e1884f0e4..dfdc4d78389 100644
--- a/gcc/opts.cc
+++ b/gcc/opts.cc
@@ -3712,7 +3712,7 @@ test_get_option_html_page ()
 /* Run all of the selftests within this file.  */
 
 void
-opts_c_tests ()
+opts_cc_tests ()
 {
   test_get_option_html_page ();
 }
diff --git a/gcc/predict.cc b/gcc/predict.cc
index 36046abff6b..5734e4c8516 100644
--- a/gcc/predict.cc
+++ b/gcc/predict.cc
@@ -4557,7 +4557,7 @@ test_prediction_value_range ()
 /* Run all of the selfests within this file.  */
 
 void
-predict_c_tests ()
+predict_cc_tests ()
 {
   test_prediction_value_range ();
 }
diff --git a/gcc/pretty-print.cc b/gcc/pretty-print.cc
index c765def5d4a..3ee206d2a42 100644
--- a/gcc/pretty-print.cc
+++ b/gcc/pretty-print.cc
@@ -2613,7 +2613,7 @@ static void test_utf8 ()
 /* Run all of the selftests within this file.  */
 
 void
-pretty_print_c_tests ()
+pretty_print_cc_tests ()
 {
   test_basic_printing ();
   test_pp_format ();
diff --git a/gcc/read-rtl-function.cc b/gcc/read-rtl-function.cc
index 85faf2f4472..49c88804a2a 100644
--- a/gcc/read-rtl-function.cc
+++ b/gcc/read-rtl-function.cc
@@ -2204,7 +2204,7 @@ test_loading_repeat ()
 /* Run all of the selftests within this file.  */
 
 void
-read_rtl_function_c_tests ()
+read_rtl_function_cc_tests ()
 {
   test_edge_flags ();
   test_parsing_regnos ();
diff --git a/gcc/rtl-tests.cc b/gcc/rtl-tests.cc
index 9b0a1261c17..6957d700ced 100644
--- a/gcc/rtl-tests.cc
+++ b/gcc/rtl-tests.cc
@@ -310,7 +310,7 @@ test_dumping_repeat ()
 /* Run all of the selftests within this file.  */
 
 void
-rtl_tests_c_tests ()
+rtl_tests_cc_tests ()
 {
   test_dumping_regs ();
   test_dumping_insns ();
diff --git a/gcc/sbitmap.cc b/gcc/sbitmap.cc
index cdbd2725543..5ac2b6d0f67 100644
--- a/gcc/sbitmap.cc
+++ b/gcc/sbitmap.cc
@@ -997,7 +997,7 @@ test_bit_in_range ()
 /* Run all of the selftests within this file.  */
 
 void
-sbitmap_c_tests ()
+sbitmap_cc_tests ()
 {
   test_set_range ();
   test_bit_in_range ();
diff --git a/gcc/selftest-run-tests.cc b/gcc/selftest-run-tests.cc
index 4123e540028..5053be0fe4f 100644
--- a/gcc/selftest-run-tests.cc
+++ b/gcc/selftest-run-tests.cc
@@ -55,67 +55,67 @@ selftest::run_tests ()
      run the tests for lowest-level code first.  */
 
   /* Sanity-check for selftests themselves.  */
-  selftest_c_tests ();
+  selftest_cc_tests ();
 
   /* Low-level data structures.  */
-  bitmap_c_tests ();
-  sbitmap_c_tests ();
-  dumpfile_c_tests ();
-  et_forest_c_tests ();
-  hash_map_tests_c_tests ();
-  hash_set_tests_c_tests ();
-  vec_c_tests ();
-  pretty_print_c_tests ();
+  bitmap_cc_tests ();
+  sbitmap_cc_tests ();
+  dumpfile_cc_tests ();
+  et_forest_cc_tests ();
+  hash_map_tests_cc_tests ();
+  hash_set_tests_cc_tests ();
+  vec_cc_tests ();
+  pretty_print_cc_tests ();
   wide_int_cc_tests ();
-  ggc_tests_c_tests ();
-  sreal_c_tests ();
-  fibonacci_heap_c_tests ();
-  typed_splay_tree_c_tests ();
-  opt_proposer_c_tests ();
-  opts_c_tests ();
+  ggc_tests_cc_tests ();
+  sreal_cc_tests ();
+  fibonacci_heap_cc_tests ();
+  typed_splay_tree_cc_tests ();
+  opt_suggestions_cc_tests ();
+  opts_cc_tests ();
   json_cc_tests ();
-  cgraph_c_tests ();
+  cgraph_cc_tests ();
   optinfo_emit_json_cc_tests ();
   opt_problem_cc_tests ();
   ordered_hash_map_tests_cc_tests ();
   splay_tree_cc_tests ();
 
   /* Mid-level data structures.  */
-  input_c_tests ();
-  vec_perm_indices_c_tests ();
-  tree_c_tests ();
-  convert_c_tests ();
-  gimple_c_tests ();
-  rtl_tests_c_tests ();
-  read_rtl_function_c_tests ();
+  input_cc_tests ();
+  vec_perm_indices_cc_tests ();
+  tree_cc_tests ();
+  convert_cc_tests ();
+  gimple_cc_tests ();
+  rtl_tests_cc_tests ();
+  read_rtl_function_cc_tests ();
   digraph_cc_tests ();
   tristate_cc_tests ();
-  ipa_modref_tree_c_tests ();
+  ipa_modref_tree_cc_tests ();
 
   /* Higher-level tests, or for components that other selftests don't
      rely on.  */
-  diagnostic_show_locus_c_tests ();
-  diagnostic_c_tests ();
+  diagnostic_show_locus_cc_tests ();
+  diagnostic_cc_tests ();
   diagnostic_format_json_cc_tests ();
-  edit_context_c_tests ();
-  fold_const_c_tests ();
-  spellcheck_c_tests ();
-  spellcheck_tree_c_tests ();
-  tree_cfg_c_tests ();
+  edit_context_cc_tests ();
+  fold_const_cc_tests ();
+  spellcheck_cc_tests ();
+  spellcheck_tree_cc_tests ();
+  tree_cfg_cc_tests ();
   tree_diagnostic_path_cc_tests ();
-  attribute_c_tests ();
+  attribute_cc_tests ();
 
   /* This one relies on most of the above.  */
-  function_tests_c_tests ();
+  function_tests_cc_tests ();
 
   /* Run any target-specific selftests.  */
   if (targetm.run_target_selftests)
     targetm.run_target_selftests ();
 
-  store_merging_c_tests ();
-  predict_c_tests ();
-  simplify_rtx_c_tests ();
-  dbgcnt_c_tests ();
+  store_merging_cc_tests ();
+  predict_cc_tests ();
+  simplify_rtx_cc_tests ();
+  dbgcnt_cc_tests ();
 
   /* Run any lang-specific selftests.  */
   lang_hooks.run_lang_selftests ();
diff --git a/gcc/selftest.cc b/gcc/selftest.cc
index ed5b3967a11..89abfba5e80 100644
--- a/gcc/selftest.cc
+++ b/gcc/selftest.cc
@@ -412,7 +412,7 @@ test_locate_file ()
 /* Run all of the selftests within this file.  */
 
 void
-selftest_c_tests ()
+selftest_cc_tests ()
 {
   test_libiberty ();
   test_assertions ();
diff --git a/gcc/selftest.h b/gcc/selftest.h
index 386c0d924e6..75302a457c9 100644
--- a/gcc/selftest.h
+++ b/gcc/selftest.h
@@ -218,56 +218,56 @@ class test_runner
 
 /* Declarations for specific families of tests (by source file), in
    alphabetical order.  */
-extern void attribute_c_tests ();
-extern void bitmap_c_tests ();
-extern void cgraph_c_tests ();
-extern void convert_c_tests ();
-extern void diagnostic_c_tests ();
+extern void attribute_cc_tests ();
+extern void bitmap_cc_tests ();
+extern void cgraph_cc_tests ();
+extern void convert_cc_tests ();
+extern void diagnostic_cc_tests ();
 extern void diagnostic_format_json_cc_tests ();
-extern void diagnostic_show_locus_c_tests ();
+extern void diagnostic_show_locus_cc_tests ();
 extern void digraph_cc_tests ();
-extern void dumpfile_c_tests ();
-extern void edit_context_c_tests ();
-extern void et_forest_c_tests ();
-extern void fibonacci_heap_c_tests ();
-extern void fold_const_c_tests ();
-extern void function_tests_c_tests ();
-extern void ggc_tests_c_tests ();
-extern void gimple_c_tests ();
-extern void hash_map_tests_c_tests ();
-extern void hash_set_tests_c_tests ();
-extern void input_c_tests ();
+extern void dumpfile_cc_tests ();
+extern void edit_context_cc_tests ();
+extern void et_forest_cc_tests ();
+extern void fibonacci_heap_cc_tests ();
+extern void fold_const_cc_tests ();
+extern void function_tests_cc_tests ();
+extern void ggc_tests_cc_tests ();
+extern void gimple_cc_tests ();
+extern void hash_map_tests_cc_tests ();
+extern void hash_set_tests_cc_tests ();
+extern void input_cc_tests ();
 extern void json_cc_tests ();
 extern void opt_problem_cc_tests ();
 extern void optinfo_emit_json_cc_tests ();
-extern void opts_c_tests ();
+extern void opts_cc_tests ();
 extern void ordered_hash_map_tests_cc_tests ();
-extern void predict_c_tests ();
-extern void pretty_print_c_tests ();
+extern void predict_cc_tests ();
+extern void pretty_print_cc_tests ();
 extern void range_tests ();
 extern void range_op_tests ();
 extern void gimple_range_tests ();
-extern void read_rtl_function_c_tests ();
-extern void rtl_tests_c_tests ();
-extern void sbitmap_c_tests ();
-extern void selftest_c_tests ();
-extern void simplify_rtx_c_tests ();
-extern void spellcheck_c_tests ();
-extern void spellcheck_tree_c_tests ();
+extern void read_rtl_function_cc_tests ();
+extern void rtl_tests_cc_tests ();
+extern void sbitmap_cc_tests ();
+extern void selftest_cc_tests ();
+extern void simplify_rtx_cc_tests ();
+extern void spellcheck_cc_tests ();
+extern void spellcheck_tree_cc_tests ();
 extern void splay_tree_cc_tests ();
-extern void sreal_c_tests ();
-extern void store_merging_c_tests ();
-extern void tree_c_tests ();
-extern void tree_cfg_c_tests ();
+extern void sreal_cc_tests ();
+extern void store_merging_cc_tests ();
+extern void tree_cc_tests ();
+extern void tree_cfg_cc_tests ();
 extern void tree_diagnostic_path_cc_tests ();
 extern void tristate_cc_tests ();
-extern void typed_splay_tree_c_tests ();
-extern void vec_c_tests ();
-extern void vec_perm_indices_c_tests ();
+extern void typed_splay_tree_cc_tests ();
+extern void vec_cc_tests ();
+extern void vec_perm_indices_cc_tests ();
 extern void wide_int_cc_tests ();
-extern void opt_proposer_c_tests ();
-extern void dbgcnt_c_tests ();
-extern void ipa_modref_tree_c_tests ();
+extern void opt_suggestions_cc_tests ();
+extern void dbgcnt_cc_tests ();
+extern void ipa_modref_tree_cc_tests ();
 
 extern int num_passes;
 
diff --git a/gcc/simplify-rtx.cc b/gcc/simplify-rtx.cc
index f17c917c296..bd176e86adf 100644
--- a/gcc/simplify-rtx.cc
+++ b/gcc/simplify-rtx.cc
@@ -8459,7 +8459,7 @@ simplify_const_poly_int_tests<N>::run ()
 /* Run all of the selftests within this file.  */
 
 void
-simplify_rtx_c_tests ()
+simplify_rtx_cc_tests ()
 {
   test_scalar_ops ();
   test_vector_ops ();
diff --git a/gcc/spellcheck-tree.cc b/gcc/spellcheck-tree.cc
index 28ad35b7301..0be1e41b15b 100644
--- a/gcc/spellcheck-tree.cc
+++ b/gcc/spellcheck-tree.cc
@@ -104,7 +104,7 @@ test_find_closest_identifier ()
 /* Run all of the selftests within this file.  */
 
 void
-spellcheck_tree_c_tests ()
+spellcheck_tree_cc_tests ()
 {
   test_find_closest_identifier ();
 }
diff --git a/gcc/spellcheck.cc b/gcc/spellcheck.cc
index 6077bed7861..3e58344f510 100644
--- a/gcc/spellcheck.cc
+++ b/gcc/spellcheck.cc
@@ -515,7 +515,7 @@ test_metric_conditions ()
 /* Run all of the selftests within this file.  */
 
 void
-spellcheck_c_tests ()
+spellcheck_cc_tests ()
 {
   test_edit_distances ();
   test_get_edit_distance_cutoff ();
diff --git a/gcc/sreal.cc b/gcc/sreal.cc
index 960f0da6fd7..75c360e3970 100644
--- a/gcc/sreal.cc
+++ b/gcc/sreal.cc
@@ -379,7 +379,7 @@ sreal_verify_negative_division (void)
 
 /* Run all of the selftests within this file.  */
 
-void sreal_c_tests ()
+void sreal_cc_tests ()
 {
   sreal_verify_basics ();
   sreal_verify_arithmetics ();
diff --git a/gcc/tree-cfg.cc b/gcc/tree-cfg.cc
index 4a8e2249496..77178a6bf69 100644
--- a/gcc/tree-cfg.cc
+++ b/gcc/tree-cfg.cc
@@ -10220,7 +10220,7 @@ test_fully_connected ()
 /* Run all of the selftests within this file.  */
 
 void
-tree_cfg_c_tests ()
+tree_cfg_cc_tests ()
 {
   test_linear_chain ();
   test_diamond ();
diff --git a/gcc/tree.cc b/gcc/tree.cc
index ae159ee20ce..c4b36619e6a 100644
--- a/gcc/tree.cc
+++ b/gcc/tree.cc
@@ -15203,7 +15203,7 @@ test_escaped_strings (void)
 /* Run all of the selftests within this file.  */
 
 void
-tree_c_tests ()
+tree_cc_tests ()
 {
   test_integer_constants ();
   test_identifiers ();
diff --git a/gcc/typed-splay-tree.cc b/gcc/typed-splay-tree.cc
index 194dd99125b..df4457c1681 100644
--- a/gcc/typed-splay-tree.cc
+++ b/gcc/typed-splay-tree.cc
@@ -72,7 +72,7 @@ test_str_to_int ()
 /* Run all of the selftests within this file.  */
 
 void
-typed_splay_tree_c_tests ()
+typed_splay_tree_cc_tests ()
 {
   test_str_to_int ();
 }
diff --git a/gcc/vec-perm-indices.cc b/gcc/vec-perm-indices.cc
index 5c2d94f84ce..acf90225280 100644
--- a/gcc/vec-perm-indices.cc
+++ b/gcc/vec-perm-indices.cc
@@ -371,7 +371,7 @@ test_vec_perm_12 (void)
 /* Run selftests for this file.  */
 
 void
-vec_perm_indices_c_tests ()
+vec_perm_indices_cc_tests ()
 {
   test_vec_perm_12 ();
 }
diff --git a/gcc/vec.cc b/gcc/vec.cc
index 1131ecbc854..af4a5e5d3ad 100644
--- a/gcc/vec.cc
+++ b/gcc/vec.cc
@@ -571,7 +571,7 @@ test_auto_delete_vec ()
 /* Run all of the selftests within this file.  */
 
 void
-vec_c_tests ()
+vec_cc_tests ()
 {
   test_init ();
   test_quick_push ();

diff --git a/gcc/toplev.cc b/gcc/toplev.cc
index 534da1462e8..ea27e441a91 100644
--- a/gcc/toplev.cc
+++ b/gcc/toplev.cc
@@ -2355,19 +2355,19 @@ toplev::finalize (void)
   rtl_initialized = false;
   this_target_rtl->target_specific_initialized = false;
 
-  /* Needs to be called before cgraph_c_finalize since it uses symtab.  */
-  ipa_reference_c_finalize ();
-  ipa_fnsummary_c_finalize ();
-  ipa_modref_c_finalize ();
+  /* Needs to be called before cgraph_cc_finalize since it uses symtab.  */
+  ipa_reference_cc_finalize ();
+  ipa_fnsummary_cc_finalize ();
+  ipa_modref_cc_finalize ();
   ipa_edge_modifications_finalize ();
 
-  cgraph_c_finalize ();
-  cgraphunit_c_finalize ();
+  cgraph_cc_finalize ();
+  cgraphunit_cc_finalize ();
   symtab_thunks_cc_finalize ();
-  dwarf2out_c_finalize ();
-  gcse_c_finalize ();
-  ipa_cp_c_finalize ();
-  ira_costs_c_finalize ();
+  dwarf2out_cc_finalize ();
+  gcse_cc_finalize ();
+  ipa_cp_cc_finalize ();
+  ira_costs_cc_finalize ();
 
   /* save_decoded_options uses opts_obstack, so these must
      be cleaned up together.  */